# Ananke

[Ananke](https://en.wikipedia.org/wiki/Ananke), named for the Greek
primordial goddess of necessity and causality, is a python package for
causal inference using the language of graphical models

## Contributors

* Rohit Bhattacharya 
* Jaron Lee
* Razieh Nabi 